pub enum BatchControl<Req: RequestWeight> {
Item(Req),
Flush,
}Expand description
Signaling mechanism for batchable services that allows explicit flushing.
This request type is a generic wrapper for the inner Req type.
Variants