pub struct BatchLayer<Request> {
max_items_weight_in_batch: usize,
max_batches: Option<usize>,
max_latency: Duration,
_handles_requests: PhantomData<fn(Request)>,
}Expand description
Adds a layer performing batch processing of requests.
The default Tokio executor is used to run the given service, which means that this layer can only be used on the Tokio runtime.
See the module documentation for more details.
Fields
max_items_weight_in_batch: usizemax_batches: Option<usize>max_latency: Duration_handles_requests: PhantomData<fn(Request)>Implementations
Sourceimpl<Request> BatchLayer<Request>
impl<Request> BatchLayer<Request>