RequestWeight

Trait RequestWeight 

pub trait RequestWeight {
    // Provided method
    fn request_weight(&self) -> usize { ... }
}
A trait for reading the weight of a request to BatchControl services.

Provided Methods

fn request_weight(&self) -> usize

Returns the weight of a request relative to the maximum threshold for flushing requests to the underlying service.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RequestWeight for &'static str

Source

impl RequestWeight for ()

Implementors