pub trait RequestWeight {
// Provided method
fn request_weight(&self) -> usize { ... }
}Expand description
A trait for reading the weight of a request to BatchControl services.
Provided Methods
Sourcefn request_weight(&self) -> usize
fn request_weight(&self) -> usize
Returns the weight of a request relative to the maximum threshold for flushing requests to the underlying service.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".